@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,7 +16,7 @@
 */
 
 #include "composerviewbasetest.h"
-#include <qtest.h>
+#include <QTest>
 #include "../src/composer/composerviewbase.h"
 
 ComposerViewBaseTest::ComposerViewBaseTest(QObject *parent)
