@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -67,7 +67,7 @@ void FollowupReminderSelectDateDialogTest::shouldHaveDefaultValue()
     Akonadi::CollectionComboBox *combobox = dlg.findChild<Akonadi::CollectionComboBox *>(QStringLiteral("collectioncombobox"));
     QVERIFY(combobox);
     QDate currentDate = QDate::currentDate();
-    QCOMPARE(datecombobox->date(), currentDate);
+    QCOMPARE(datecombobox->date(), currentDate.addDays(1));
 
     QPushButton *okButton = dlg.findChild<QPushButton *>(QStringLiteral("ok_button"));
     QVERIFY(okButton);
