@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,7 +18,7 @@
 */
 
 #include "globalparttest.h"
-#include <qtest.h>
+#include <QTest>
 #include <../src/part/globalpart.h>
 GlobalPartTest::GlobalPartTest(QObject *parent)
     : QObject(parent)
