@@ -23,8 +23,7 @@
 #include <QStandardPaths>
 
 #include <QDebug>
-#include <KIconLoader>
-#include <qtest.h>
+#include <QTest>
 
 #include <kmime/kmime_content.h>
 using namespace KMime;
@@ -55,7 +54,7 @@ void MainTextJobTest::testPlainText()
 {
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
-    QList<QByteArray> charsets;
+    QVector<QByteArray> charsets;
     charsets << "us-ascii" << "utf-8";
     composer->globalPart()->setCharsets(charsets);
     TextPart *textPart = new TextPart;
@@ -105,7 +104,7 @@ void MainTextJobTest::testCustomCharset()
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
     QByteArray charset("iso-8859-2");
-    composer->globalPart()->setCharsets(QList<QByteArray>() << charset);
+    composer->globalPart()->setCharsets(QVector<QByteArray>() << charset);
     TextPart *textPart = new TextPart;
     QString data = QStringLiteral("şi el o să se-nchidă cu o frunză de pelin");
     textPart->setWrappedPlainText(data);
@@ -143,7 +142,7 @@ void MainTextJobTest::testBadCharset()
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
     QByteArray charset("us-ascii");   // Cannot handle Romanian chars.
-    composer->globalPart()->setCharsets(QList<QByteArray>() << charset);
+    composer->globalPart()->setCharsets(QVector<QByteArray>() << charset);
     TextPart *textPart = new TextPart;
     QString data = QStringLiteral("el a plâns peste ţară cu lacrima limbii noastre");
     textPart->setWrappedPlainText(data);
@@ -223,14 +222,22 @@ void MainTextJobTest::testHtmlWithImages()
     MessageComposer::RichTextComposerNg editor;
     editor.createActions(new KActionCollection(this));
 
-    QString image1 = KIconLoader::global()->iconPath(QStringLiteral("folder-new"), KIconLoader::Small, false);
-    QString image2 = KIconLoader::global()->iconPath(QStringLiteral("message"), KIconLoader::Small, false);
+    QImage image1(16, 16, QImage::Format_ARGB32_Premultiplied);
+    image1.fill(Qt::red);
+    const QString image1Path = QCoreApplication::applicationDirPath() + QLatin1String("/image1.png");
+    image1.save(image1Path);
+
+    QImage image2(16, 16, QImage::Format_ARGB32_Premultiplied);
+    image2.fill(Qt::blue);
+    const QString image2Path = QCoreApplication::applicationDirPath() + QLatin1String("/image2.png");
+    image2.save(image2Path);
+
     QString data = QStringLiteral("dust in the wind");
     editor.setTextOrHtml(data);
-    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image1));
-    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image1));
-    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image2));
-    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image2));
+    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image1Path));
+    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image1Path));
+    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image2Path));
+    editor.composerControler()->composerImages()->addImage(QUrl::fromLocalFile(image2Path));
     KPIMTextEdit::ImageList images = editor.composerControler()->composerImages()->embeddedImages();
     QCOMPARE(images.count(), 2);
     QString cid1 = images[0]->contentID;
@@ -303,4 +310,3 @@ void MainTextJobTest::testHtmlWithImages()
         }
     }
 }
-
