@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include <KLocalizedString>
 #include <QApplication>
 #include <QClipboard>
-#include <qinputdialog.h>
+#include <QInputDialog>
 
 using namespace MessageComposer;
 
