@@ -34,6 +34,8 @@
 #include <mailtransport/transport.h>
 #include <mailtransport/transportmanager.h>
 #include <MessageCore/StringUtil>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
 using namespace KMime::Types;
 using namespace KPIM;
@@ -75,17 +77,16 @@ class MessageComposer::AkonadiSenderPrivate
 {
 public:
     AkonadiSenderPrivate()
-        : mCustomTransportId(-1)
     {
-
     }
+
     QSet<KJob *> mPendingJobs;
-    int mCustomTransportId;
+    int mCustomTransportId = -1;
 };
 
 AkonadiSender::AkonadiSender(QObject *parent)
-    : QObject(parent),
-      d(new MessageComposer::AkonadiSenderPrivate)
+    : QObject(parent)
+    , d(new MessageComposer::AkonadiSenderPrivate)
 {
 }
 
@@ -140,6 +141,26 @@ void AkonadiSender::sendOrQueueMessage(const KMime::Message::Ptr &message, Messa
         const int sentCollectionId = hrd->asUnicodeString().toInt();
         qjob->sentBehaviourAttribute().setMoveToCollection(
             Akonadi::Collection(sentCollectionId));
+    } else if (auto hrd = message->headerByType("X-KMail-Identity")) {
+        KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
+        const QString identityStrId = hrd->asUnicodeString();
+        const KIdentityManagement::Identity id = im->modifyIdentityForUoid(identityStrId.toUInt());
+        const QString fccId = id.fcc();
+        qjob->sentBehaviourAttribute().setSentBehaviour(
+            SentBehaviourAttribute::MoveToCollection);
+        const int sentCollectionId = fccId.toInt();
+        qjob->sentBehaviourAttribute().setMoveToCollection(
+            Akonadi::Collection(sentCollectionId));
+    } else if (auto hrd = message->headerByType("X-KMail-Identity-Name")) {
+        KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
+        const QString identityStrName = hrd->asUnicodeString();
+        const KIdentityManagement::Identity id = im->modifyIdentityForName(identityStrName);
+        const QString fccId = id.fcc();
+        qjob->sentBehaviourAttribute().setSentBehaviour(
+            SentBehaviourAttribute::MoveToCollection);
+        const int sentCollectionId = fccId.toInt();
+        qjob->sentBehaviourAttribute().setMoveToCollection(
+            Akonadi::Collection(sentCollectionId));
     } else {
         qjob->sentBehaviourAttribute().setSentBehaviour(
             MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
@@ -209,4 +230,3 @@ void AkonadiSender::queueJobResult(KJob *job)
         qCDebug(MESSAGECOMPOSER_LOG) << "QueueJob success.";
     }
 }
-
