@@ -28,34 +28,26 @@
 #include <AkonadiCore/Item>
 #include <Akonadi/KMime/MessageStatus>
 
-namespace KMime
-{
+class QTextDocument;
+
+namespace KMime {
 class Content;
 }
 
-namespace MailTransport
-{
-class MessageQueueJob;
-}
+namespace MessageComposer {
+namespace Util {
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT QByteArray selectCharset(const QVector<QByteArray> &charsets, const QString &text);
 
-namespace MessageComposer
-{
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT QStringList AttachmentKeywords();
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT QString cleanedUpHeaderString(const QString &s);
 
-namespace Util
-{
-MESSAGECOMPOSER_EXPORT QByteArray selectCharset(const QList<QByteArray> &charsets,
-        const QString &text);
-
-MESSAGECOMPOSER_EXPORT QStringList AttachmentKeywords();
-MESSAGECOMPOSER_EXPORT QString cleanedUpHeaderString(const QString &s);
-
-MESSAGECOMPOSER_EXPORT bool sendMailDispatcherIsOnline(QWidget *parent = nullptr);
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool sendMailDispatcherIsOnline(QWidget *parent = nullptr);
 MESSAGECOMPOSER_EXPORT void removeNotNecessaryHeaders(const KMime::Message::Ptr &msg);
 
 /**
  * find mimetype in message
  */
-MESSAGECOMPOSER_EXPORT KMime::Content *findTypeInMessage(KMime::Content *data, const QByteArray &mimeType, const QByteArray &subType);
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT KMime::Content *findTypeInMessage(KMime::Content *data, const QByteArray &mimeType, const QByteArray &subType);
 
 /**
    * Adds private headers to the given @p message that links it to the original message.
@@ -74,7 +66,7 @@ MESSAGECOMPOSER_EXPORT void addLinkInformation(const KMime::Message::Ptr &messag
    * @param status Will contain the status (replied or forwarded) that linked the message to the original message.
    * @returns Whether the mail contains valid link information or not.
    */
-MESSAGECOMPOSER_EXPORT bool getLinkInformation(const KMime::Message::Ptr &msg, QList<Akonadi::Item::Id> &id, QList<Akonadi::MessageStatus> &status);
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool getLinkInformation(const KMime::Message::Ptr &msg, QVector<Akonadi::Item::Id> &id, QVector<Akonadi::MessageStatus> &status);
 
 /**
    * Returns whether the item represents a valid KMime::Message that is not
@@ -83,17 +75,17 @@ MESSAGECOMPOSER_EXPORT bool getLinkInformation(const KMime::Message::Ptr &msg, Q
    * the akonadi sense, since jobs cannot sensibly use them, but they do
    * contain a valid message pointer.
    */
-MESSAGECOMPOSER_EXPORT bool isStandaloneMessage(const Akonadi::Item &item);
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool isStandaloneMessage(const Akonadi::Item &item);
 
 /**
    * Retrieve the KMime::Message from the item, if there is one.
    * @returns A valid message pointer, or 0, is the item does not contain
    * a valid message.
    */
-MESSAGECOMPOSER_EXPORT KMime::Message::Ptr message(const Akonadi::Item &item);
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT KMime::Message::Ptr message(const Akonadi::Item &item);
 
+Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool hasMissingAttachments(const QStringList &attachmentKeywords, QTextDocument *doc, const QString &subj);
 }
-
 }
 
 #endif
