@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@
 namespace MessageCore {
 class AttachmentFromUrlBaseJob;
 namespace AttachmentFromUrlUtils {
-MESSAGECORE_EXPORT MessageCore::AttachmentFromUrlBaseJob *createAttachmentJob(const QUrl &url, QObject *parent);
+Q_REQUIRED_RESULT MESSAGECORE_EXPORT MessageCore::AttachmentFromUrlBaseJob *createAttachmentJob(const QUrl &url, QObject *parent);
 }
 }
 
