@@ -43,7 +43,7 @@
 #include <QVariant>
 
 #include <QAction>
-#include <KComboBox>
+#include <QComboBox>
 #include "messagelist_debug.h"
 #include <KLocalizedString>
 #include <QMenu>
@@ -135,7 +135,7 @@ Widget::Widget(QWidget *pParent)
     setObjectName(QStringLiteral("messagelistwidget"));
 
     QVBoxLayout *g = new QVBoxLayout(this);
-    g->setMargin(0);
+    g->setContentsMargins(0, 0, 0, 0);
     g->setSpacing(0);
 
     d->quickSearchLine = new QuickSearchLine;
@@ -206,9 +206,13 @@ void Widget::populateStatusFilterCombo()
         return;
     }
     d->mStatusFilterComboPopulationInProgress = true;
-    KComboBox *tagFilterComboBox = d->quickSearchLine->tagFilterComboBox();
+    QComboBox *tagFilterComboBox = d->quickSearchLine->tagFilterComboBox();
     d->mCurrentStatusFilterIndex = (tagFilterComboBox->currentIndex() != -1) ? tagFilterComboBox->currentIndex() : 0;
-    disconnect(tagFilterComboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &Widget::statusSelected);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    disconnect(tagFilterComboBox, qOverload<int>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
+#else
+    disconnect(tagFilterComboBox, qOverload<int, const QString &>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
+#endif
 
     tagFilterComboBox->clear();
 
@@ -223,8 +227,11 @@ void Widget::addMessageTagItem(const QPixmap &icon, const QString &text, const Q
 void Widget::setCurrentStatusFilterItem()
 {
     d->quickSearchLine->updateComboboxVisibility();
-    connect(d->quickSearchLine->tagFilterComboBox(), QOverload<int>::of(&KComboBox::currentIndexChanged),
-            this, &Widget::statusSelected);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    connect(d->quickSearchLine->tagFilterComboBox(), qOverload<int>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
+#else
+    connect(d->quickSearchLine->tagFilterComboBox(), qOverload<int, const QString &>(&QComboBox::currentIndexChanged), this, &Widget::statusSelected);
+#endif
     d->quickSearchLine->tagFilterComboBox()->setCurrentIndex(d->mCurrentStatusFilterIndex >= d->quickSearchLine->tagFilterComboBox()->count() ? 0 : d->mCurrentStatusFilterIndex);
     d->mStatusFilterComboPopulationInProgress = false;
 }
@@ -239,12 +246,12 @@ MessageList::Core::QuickSearchLine::SearchOptions Widget::currentOptions() const
     return d->quickSearchLine->searchOptions();
 }
 
-QList<Akonadi::MessageStatus> Widget::currentFilterStatus() const
+QVector<Akonadi::MessageStatus> Widget::currentFilterStatus() const
 {
     if (d->mFilter) {
         return d->mFilter->status();
     }
-    return QList<Akonadi::MessageStatus>();
+    return QVector<Akonadi::MessageStatus>();
 }
 
 QString Widget::currentFilterSearchString() const
@@ -579,7 +586,7 @@ void Widget::sortOrderMenuAboutToShow(QMenu *menu)
 
     QActionGroup *grp;
     QAction *act;
-    QList< QPair< QString, int > > options;
+    QVector< QPair< QString, int > > options;
 
     grp = new QActionGroup(menu);
 
@@ -959,7 +966,7 @@ void Widget::searchEditTextEdited()
 
 void Widget::slotStatusButtonsClicked()
 {
-    // We also arbitrairly set tagId to an empty string, though we *could* allow filtering
+    // We also arbitrarily set tagId to an empty string, though we *could* allow filtering
     // by status AND tag...
     if (d->mFilter) {
         d->mFilter->setTagId(QString());
@@ -1038,7 +1045,7 @@ void Widget::viewSelectionChanged()
 {
 }
 
-void Widget::viewMessageListContextPopupRequest(const QList< MessageItem * > &, const QPoint &)
+void Widget::viewMessageListContextPopupRequest(const QVector< MessageItem * > &, const QPoint &)
 {
 }
 
