@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
@@ -25,10 +25,9 @@
 
 #include "searchlinestatus.h"
 #include <KLocalizedString>
-#include <KComboBox>
 
 #include <QPushButton>
-
+#include <QComboBox>
 #include <QHBoxLayout>
 #include <QStandardPaths>
 
@@ -61,7 +60,7 @@ QuickSearchLine::QuickSearchLine(QWidget *parent)
     hbox->addWidget(mSearchEdit);
 
     // The status filter button. Will be populated later, as populateStatusFilterCombo() is virtual
-    mTagFilterCombo = new KComboBox(this);
+    mTagFilterCombo = new QComboBox(this);
     mTagFilterCombo->setMaximumWidth(300);
     mTagFilterCombo->setMaximumWidth(200);
     mTagFilterCombo->hide();
@@ -117,7 +116,7 @@ void QuickSearchLine::focusQuickSearch(const QString &selectedText)
     mSearchEdit->setFocus();
 }
 
-KComboBox *QuickSearchLine::tagFilterComboBox() const
+QComboBox *QuickSearchLine::tagFilterComboBox() const
 {
     return mTagFilterCombo;
 }
@@ -136,13 +135,13 @@ void QuickSearchLine::resetFilter()
     mSearchEdit->setLocked(false);
 }
 
-void QuickSearchLine::slotFilterActionChanged(const QList<Akonadi::MessageStatus> &lst)
+void QuickSearchLine::slotFilterActionChanged(const QVector<Akonadi::MessageStatus> &lst)
 {
     mLstStatus = lst;
     Q_EMIT statusButtonsClicked();
 }
 
-QList<Akonadi::MessageStatus> QuickSearchLine::status() const
+QVector<Akonadi::MessageStatus> QuickSearchLine::status() const
 {
     return mLstStatus;
 }
