@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,6 +30,9 @@ public:
     ~DKIMCheckAuthenticationStatusJobTest() = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
+    void shouldTestMail();
+    void shouldTestMail_data();
+    void initTestCase();
 };
 
 #endif // DKIMCHECKAUTHENTICATIONSTATUSJOBTEST_H
