@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,13 +21,21 @@
 #define DKIMCHECKSIGNATUREJOBTEST_H
 
 #include <QObject>
-
+#include <QtCrypto>
 class DKIMCheckSignatureJobTest : public QObject
 {
     Q_OBJECT
 public:
     explicit DKIMCheckSignatureJobTest(QObject *parent = nullptr);
     ~DKIMCheckSignatureJobTest() = default;
+private Q_SLOTS:
+    void shouldHaveDefaultValues();
+    void shouldTestMail();
+    void shouldTestMail_data();
+    void initTestCase();
+    void cleanupTestCase();
+private:
+    QCA::Initializer *mQcaInitializer = nullptr;
 };
 
 #endif // DKIMCHECKSIGNATUREJOBTEST_H
