@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,6 +28,10 @@ class DKIMDownloadKeyJobTest : public QObject
 public:
     explicit DKIMDownloadKeyJobTest(QObject *parent = nullptr);
     ~DKIMDownloadKeyJobTest() = default;
+private Q_SLOTS:
+    void shouldHaveDefaultValues();
+    void shouldTestCanStart();
+    void shouldVerifyResolveDns();
 };
 
 #endif // DKIMDOWNLOADKEYJOBTEST_H
