@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,6 +32,10 @@ DKIMCheckPolicy::DKIMCheckPolicy()
     mUseDMarc = MessageViewer::MessageViewerSettings::useDMarc();
     mUseDefaultRules = MessageViewer::MessageViewerSettings::useDefaultRules();
     mUseAuthenticationResults = MessageViewer::MessageViewerSettings::useAuthenticationResults();
+    mUseRelaxedParsing = MessageViewer::MessageViewerSettings::useRelaxedParsingAuthenticationResults();
+    mUseOnlyAuthenticationResults = MessageViewer::MessageViewerSettings::useOnlyAuthenticationResults();
+    mAutogenerateRuleOnlyIfSenderInSDID = MessageViewer::MessageViewerSettings::autogenerateRuleOnlyIfSenderOnSDID();
+    mPublicRsaTooSmallPolicy = MessageViewer::MessageViewerSettings::publicRsaTooSmall();
 }
 
 int DKIMCheckPolicy::rsaSha1Policy() const
@@ -64,12 +68,12 @@ void DKIMCheckPolicy::setSaveDkimResult(bool saveDkimResult)
     mSaveDkimResult = saveDkimResult;
 }
 
-bool DKIMCheckPolicy::saveKey() const
+int DKIMCheckPolicy::saveKey() const
 {
     return mSaveKey;
 }
 
-void DKIMCheckPolicy::setSaveKey(bool saveKey)
+void DKIMCheckPolicy::setSaveKey(int saveKey)
 {
     mSaveKey = saveKey;
 }
@@ -123,3 +127,43 @@ void DKIMCheckPolicy::setUseAuthenticationResults(bool useAuthenticationResults)
 {
     mUseAuthenticationResults = useAuthenticationResults;
 }
+
+bool DKIMCheckPolicy::useRelaxedParsing() const
+{
+    return mUseRelaxedParsing;
+}
+
+void DKIMCheckPolicy::setUseRelaxedParsing(bool useRelaxedParsing)
+{
+    mUseRelaxedParsing = useRelaxedParsing;
+}
+
+bool DKIMCheckPolicy::useOnlyAuthenticationResults() const
+{
+    return mUseOnlyAuthenticationResults;
+}
+
+void DKIMCheckPolicy::setUseOnlyAuthenticationResults(bool useOnlyAuthenticationResults)
+{
+    mUseOnlyAuthenticationResults = useOnlyAuthenticationResults;
+}
+
+bool DKIMCheckPolicy::autogenerateRuleOnlyIfSenderInSDID() const
+{
+    return mAutogenerateRuleOnlyIfSenderInSDID;
+}
+
+void DKIMCheckPolicy::setAutogenerateRuleOnlyIfSenderInSDID(bool autogenerateRuleOnlyIfSenderInSDID)
+{
+    mAutogenerateRuleOnlyIfSenderInSDID = autogenerateRuleOnlyIfSenderInSDID;
+}
+
+int DKIMCheckPolicy::publicRsaTooSmallPolicy() const
+{
+    return mPublicRsaTooSmallPolicy;
+}
+
+void DKIMCheckPolicy::setPublicRsaTooSmallPolicy(int publicRsaTooSmallPolicy)
+{
+    mPublicRsaTooSmallPolicy = publicRsaTooSmallPolicy;
+}
