@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,8 +25,8 @@
 #include <MessageViewer/DKIMKeyRecord>
 #include <MessageViewer/DKIMInfo>
 #include <MessageViewer/DKIMCheckPolicy>
+#include <MessageViewer/DKIMHeaderParser>
 #include <KMime/Message>
-#include <AkonadiCore/Item>
 
 namespace MessageViewer {
 /**
@@ -77,9 +77,30 @@ public:
         SignatureCreatedInFuture = 2,
         SignatureTooSmall = 3,
         HashAlgorithmUnsafe = 4,
+        PublicRsaKeyTooSmall = 5,
     };
     Q_ENUM(DKIMWarning)
 
+    enum class AuthenticationMethod : int {
+        Unknown = 0,
+        Dkim = 1,
+        Spf = 2,
+        Dmarc = 3,
+        Dkimatps = 4,
+    };
+    Q_ENUM(AuthenticationMethod)
+
+
+    struct DKIMCheckSignatureAuthenticationResult {
+        QString errorStr;
+        AuthenticationMethod method = AuthenticationMethod::Unknown;
+        DKIMCheckSignatureJob::DKIMStatus status = DKIMCheckSignatureJob::DKIMStatus::Unknown;
+        QString sdid; //Signing Domain Identifier
+        QString auid; //DKIM MAY optionally provide a single responsible Agent or User Identifier (AUID).
+        Q_REQUIRED_RESULT bool operator==(const DKIMCheckSignatureAuthenticationResult &other) const;
+        Q_REQUIRED_RESULT bool isValid() const;
+    };
+
     struct CheckSignatureResult {
         Q_REQUIRED_RESULT bool isValid() const;
 
@@ -90,9 +111,11 @@ public:
         DKIMCheckSignatureJob::DKIMError error = DKIMCheckSignatureJob::DKIMError::Any;
         DKIMCheckSignatureJob::DKIMWarning warning = DKIMCheckSignatureJob::DKIMWarning::Any;
         DKIMCheckSignatureJob::DKIMStatus status = DKIMCheckSignatureJob::DKIMStatus::Unknown;
-        Akonadi::Item item;
-        QString signedBy;
+        QString sdid; //Signing Domain Identifier
+        QString auid; //DKIM MAY optionally provide a single responsible Agent or User Identifier (AUID).
         QString fromEmail;
+
+        QVector<DKIMCheckSignatureAuthenticationResult> listSignatureAuthenticationResult;
     };
 
     explicit DKIMCheckSignatureJob(QObject *parent = nullptr);
@@ -102,7 +125,7 @@ public:
     Q_REQUIRED_RESULT QString dkimValue() const;
 
     Q_REQUIRED_RESULT DKIMCheckSignatureJob::DKIMStatus status() const;
-    void setStatus(const DKIMCheckSignatureJob::DKIMStatus &status);
+    void setStatus(MessageViewer::DKIMCheckSignatureJob::DKIMStatus status);
 
     Q_REQUIRED_RESULT MessageViewer::DKIMCheckSignatureJob::DKIMStatus checkSignature(const MessageViewer::DKIMInfo &info);
 
@@ -112,18 +135,19 @@ public:
     void setMessage(const KMime::Message::Ptr &message);
 
     Q_REQUIRED_RESULT DKIMCheckSignatureJob::DKIMWarning warning() const;
-    void setWarning(const DKIMWarning &warning);
+    void setWarning(MessageViewer::DKIMCheckSignatureJob::DKIMWarning warning);
 
     Q_REQUIRED_RESULT QString headerCanonizationResult() const;
 
     Q_REQUIRED_RESULT QString bodyCanonizationResult() const;
 
-    Q_REQUIRED_RESULT Akonadi::Item item() const;
-    void setItem(const Akonadi::Item &item);
-
     Q_REQUIRED_RESULT DKIMCheckPolicy policy() const;
     void setPolicy(const DKIMCheckPolicy &policy);
 
+    void setHeaderParser(const DKIMHeaderParser &headerParser);
+
+    void setCheckSignatureAuthenticationResult(const QVector<DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult> &lst);
+
 Q_SIGNALS:
     void result(const MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult &checkResult);
     void storeKey(const QString &key, const QString &domain, const QString &selector);
@@ -139,9 +163,10 @@ private:
     Q_REQUIRED_RESULT MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult createCheckResult();
     void verifyRSASignature();
     void computeHeaderCanonization(bool removeQuoteOnContentType);
+    QVector<DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult> mCheckSignatureAuthenticationResult;
     DKIMCheckPolicy mPolicy;
+    DKIMHeaderParser mHeaderParser;
     KMime::Message::Ptr mMessage;
-    Akonadi::Item mMessageItem;
     QString mFromEmail;
     DKIMInfo mDkimInfo;
     DKIMKeyRecord mDkimKeyRecord;
@@ -153,5 +178,8 @@ private:
     DKIMCheckSignatureJob::DKIMStatus mStatus = DKIMCheckSignatureJob::DKIMStatus::Unknown;
 };
 }
+MESSAGEVIEWER_EXPORT QDebug operator <<(QDebug d, const MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult &t);
+MESSAGEVIEWER_EXPORT QDebug operator <<(QDebug d, const MessageViewer::DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &t);
 Q_DECLARE_METATYPE(MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult)
+Q_DECLARE_TYPEINFO(MessageViewer::DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult, Q_MOVABLE_TYPE);
 #endif // DKIMCHECKSIGNATUREJOB_H
