@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,21 +21,43 @@
 #define DKIMDOWNLOADKEYJOB_H
 
 #include <QObject>
+#include "messageviewer_export.h"
+class QDnsLookup;
 namespace MessageViewer {
-class DKIMDownloadKeyJob : public QObject
+/**
+ * @brief The DKIMDownloadKeyJob class
+ * @author Laurent Montel <montel@kde.org>
+ */
+class MESSAGEVIEWER_EXPORT DKIMDownloadKeyJob : public QObject
 {
     Q_OBJECT
 public:
     explicit DKIMDownloadKeyJob(QObject *parent = nullptr);
     ~DKIMDownloadKeyJob();
 
-    void start();
+    Q_REQUIRED_RESULT bool start();
 
-    bool canStart() const;
+    Q_REQUIRED_RESULT bool canStart() const;
+
+    Q_REQUIRED_RESULT QString domainName() const;
+    void setDomainName(const QString &domainName);
+
+    Q_REQUIRED_RESULT QString selectorName() const;
+    void setSelectorName(const QString &selectorName);
+
+    Q_REQUIRED_RESULT QString resolvDnsValue() const;
+
+    QDnsLookup *dnsLookup() const;
 
 Q_SIGNALS:
-    void success();
-    void error(const QString &err);
+    void error(const QString &error);
+    void success(const QList<QByteArray> &, const QString &domain, const QString &selector);
+
+private:
+    void resolvDnsDone();
+    QString mDomainName;
+    QString mSelectorName;
+    QDnsLookup *mDnsLookup = nullptr;
 };
 }
 
