@@ -15,16 +15,17 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 #include "grantleeheaderformattertest.h"
 
 #include <MessageViewer/GrantleeHeaderStyle>
+#include <MimeTreeParser/NodeHelper>
 #include "../grantleeheaderformatter.h"
 
 #include <QFile>
 #include <QProcess>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QStandardPaths>
 #include <QTest>
@@ -42,11 +43,11 @@ void testHeaderFile(const QString &data, const QString &absolutePath, const QStr
     header += QStringLiteral("\n</body>\n</html>\n");
 
     header.replace(QStringLiteral("file://") + absolutePath, QStringLiteral("file://PATHTOSTYLE"));
-    header.replace(QRegExp(QStringLiteral("[\t ]+")), QStringLiteral(" "));
-    header.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*")), QStringLiteral("\n"));
-    header.replace(QRegExp(QStringLiteral("([\n\t ])\\1+")), QStringLiteral("\\1"));
-    header.replace(QRegExp(QStringLiteral(">\n+[\t ]*")), QStringLiteral(">"));
-    header.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*<")), QStringLiteral("<"));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]+")), QStringLiteral(" "));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]*\n+[\t ]*")), QStringLiteral("\n"));
+    header.replace(QRegularExpression(QStringLiteral("([\n\t ])\\1+")), QStringLiteral("\\1"));
+    header.replace(QRegularExpression(QStringLiteral(">\n+[\t ]*")), QStringLiteral(">"));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]*\n+[\t ]*<")), QStringLiteral("<"));
     header.replace(QLatin1String("&nbsp;"), QLatin1String("NBSP_ENTITY_PLACEHOLDER")); // xmlling chokes on &nbsp;
 
     QString outName = name + QStringLiteral(".out.html");
@@ -102,6 +103,8 @@ void GrantleeHeaderFormatterTest::testInvalid()
 {
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     auto aMsg = readAndParseMail(QStringLiteral("allheaders.mbox"));
 
     QString filename = QStringLiteral("invalid");
@@ -117,6 +120,8 @@ void GrantleeHeaderFormatterTest::testPrint()
 
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     KMime::Message::Ptr aMsg(new KMime::Message);
 
     const QString &absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
@@ -132,6 +137,32 @@ void GrantleeHeaderFormatterTest::testPrint()
     }
 }
 
+void GrantleeHeaderFormatterTest::testFancyDate()
+{
+    QString tmplName = QStringLiteral("fancydate.tmpl");
+
+    auto style = GrantleeHeaderStyle();
+    auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
+    KMime::Message::Ptr msg(new KMime::Message);
+
+    {
+        auto datetime(QDateTime::currentDateTime());
+        datetime.setTime(QTime(12, 34, 56));
+        datetime = datetime.addDays(-1);
+
+        const QByteArray data = "From: from@example.com\nDate: " + datetime.toString(Qt::RFC2822Date).toLocal8Bit() + "\nTo: to@example.com\n\ncontent";
+        msg->setContent(KMime::CRLFtoLF(data));
+        msg->parse();
+    }
+
+    const QString &absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
+
+    const QString &data = formatter.toHtml(QStringList(), QStringLiteral(HEADER_DATA_DIR), tmplName, &style, msg.data(), false);
+    testHeaderFile(QStringLiteral("<div><div>")+data, absolutePath, QStringLiteral("fancydate"));
+}
+
 void GrantleeHeaderFormatterTest::testBlock_data()
 {
     QTest::addColumn<QString>("tmplName");
@@ -152,6 +183,8 @@ void GrantleeHeaderFormatterTest::testBlock()
 
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     auto aMsg = readAndParseMail(QStringLiteral("headertest.mbox"));
 
     QString absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
