@@ -20,12 +20,13 @@
 #include "grantleeheaderstyletest.h"
 
 #include <MessageViewer/GrantleeHeaderStyle>
+#include <MimeTreeParser/NodeHelper>
 
 #include <GrantleeTheme/GrantleeThemeManager>
 
 #include <QFile>
 #include <QProcess>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QStandardPaths>
 #include <QTest>
@@ -39,15 +40,15 @@ void testHeaderFile(const HeaderStyle &style, KMime::Message *msg, const QString
     QString header = QStringLiteral("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n"
                                     "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
                                     "<body>\n");
-    header += style.format(msg) + QStringLiteral("</div>\n</div>");
+    header += style.format(msg) + QStringLiteral("</div>");
     header += QStringLiteral("\n</body>\n</html>\n");
 
     header.replace(QStringLiteral("file://") + style.theme().absolutePath(), QStringLiteral("file://PATHTOSTYLE"));
-    header.replace(QRegExp(QStringLiteral("[\t ]+")), QStringLiteral(" "));
-    header.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*")), QStringLiteral("\n"));
-    header.replace(QRegExp(QStringLiteral("([\n\t ])\\1+")), QStringLiteral("\\1"));
-    header.replace(QRegExp(QStringLiteral(">\n+[\t ]*")), QStringLiteral(">"));
-    header.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*<")), QStringLiteral("<"));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]+")), QStringLiteral(" "));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]*\n+[\t ]*")), QStringLiteral("\n"));
+    header.replace(QRegularExpression(QStringLiteral("([\n\t ])\\1+")), QStringLiteral("\\1"));
+    header.replace(QRegularExpression(QStringLiteral(">\n+[\t ]*")), QStringLiteral(">"));
+    header.replace(QRegularExpression(QStringLiteral("[\t ]*\n+[\t ]*<")), QStringLiteral("<"));
     header.replace(QLatin1String("&nbsp;"), QLatin1String("NBSP_ENTITY_PLACEHOLDER")); // xmlling chokes on &nbsp;
 
     QString outName = name + QStringLiteral(".out.html");
@@ -99,6 +100,47 @@ KMime::Message::Ptr readAndParseMail(const QString &mailFile)
     return msg;
 }
 
+void GrantleeHeaderStyleTest::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+    qputenv("LC_ALL", "C");
+    expectedDataLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
+    expectedDataLocation += QDir::separator() + QStringLiteral("messageviewer/defaultthemes");
+    QDir targetDir(expectedDataLocation);
+    QDir sourceDir(QStringLiteral(GRANTLEETHEME_DATA_DIR));
+    const auto themeDirs = sourceDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot);
+
+    if (targetDir.exists()) {
+        QVERIFY(targetDir.removeRecursively()); // Start with a fresh copy
+    }
+
+    for (const auto &themeDir : themeDirs) {
+        const QString &dirName = targetDir.filePath(themeDir.fileName());
+        QVERIFY(targetDir.mkpath(themeDir.fileName()));
+        const auto files = QDir(themeDir.absoluteFilePath()).entryInfoList(QDir::Files | QDir::Readable | QDir::NoSymLinks);
+        for (const auto &file : files) {
+            const QString &newPath = dirName + QDir::separator() + file.fileName();
+            QVERIFY(QFile(file.absoluteFilePath()).copy(newPath));
+        }
+    }
+    const auto configDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
+    if (!configDir.exists()) {
+        QVERIFY(configDir.mkpath(QStringLiteral(".")));
+    }
+    QFile antispamFile(QStringLiteral(HEADER_DATA_DIR "/kmail.antispamrc"));
+    const QString &newPath = configDir.filePath(QStringLiteral("kmail.antispamrc"));
+    antispamFile.copy(newPath);
+}
+
+void GrantleeHeaderStyleTest::cleanupTestCase()
+{
+    QDir targetDir(expectedDataLocation);
+
+    if (targetDir.exists()) {
+        QVERIFY(targetDir.removeRecursively()); // Start with a fresh copy
+    }
+}
+
 const GrantleeTheme::Theme defaultTheme(const QString &name = QStringLiteral("5.2"))
 {
     const QStringList defaultThemePath = QStandardPaths::locateAll(
@@ -167,6 +209,8 @@ void GrantleeHeaderStyleTest::testRenderHeader()
     QFETCH(QString, mailFileName);
 
     auto style = GrantleeHeaderStyle();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     auto aMsg = readAndParseMail(mailFileName);
     style.setTheme(defaultTheme());
 
