@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,7 +22,7 @@
 #include "globalsettings_base.h"
 #include <messageviewer/grantleeheaderstyle.h>
 #include "defaultgrantleeheaderstrategy.h"
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 using namespace MessageViewer;
 
 K_PLUGIN_CLASS_WITH_JSON(DefaultGrantleeHeaderStylePlugin,
