@@ -158,7 +158,7 @@ bool Util::checkOverwrite(const QUrl &url, QWidget *w)
 #if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto job = KIO::stat(url, KIO::StatJob::DestinationSide, 0, KIO::JobFlag::DefaultFlags);
 #else
-        auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatDetail::Basic);
+        auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatBasic);
 #endif
         KJobWidgets::setWindow(job, w);
         fileExists = job->exec();
@@ -324,7 +324,7 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
 #if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
                     auto job = KIO::stat(curUrl, KIO::StatJob::DestinationSide, 0);
 #else
-                    auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatDetail::Basic);
+                    auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatDetail::StatBasic);
 #endif
                     KJobWidgets::setWindow(job, parent);
                     fileExists = job->exec();
@@ -735,3 +735,17 @@ QString Util::processHtml(const QString &htmlSource, QString &extraHead)
     s = textBeforeDoctype + s;
     return s;
 }
+
+
+QByteArray Util::htmlCodec(const QByteArray &data, const QByteArray &codec)
+{
+    QByteArray currentCodec = codec;
+    if (currentCodec.isEmpty()) {
+        currentCodec = QByteArray("UTF-8");
+    }
+    //qDebug() << " codecValue ******************************************: " << codecValue;
+    if (data.contains("<meta charset=\"utf-8\">")) {
+        currentCodec = QByteArray("UTF-8");
+    }
+    return currentCodec;
+}
