@@ -23,6 +23,7 @@
 #define MESSAGEVIEWER_H
 
 #include "messageviewer_export.h"
+#include "config-messageviewer.h"
 #include "messageviewer/viewerplugininterface.h"
 #include <MimeTreeParser/Enums>
 
@@ -51,17 +52,18 @@ class WebHitTestResult;
 
 namespace MessageViewer {
 class WebHitTestResult;
-
+class DKIMWidgetInfo;
+class DKIMViewerMenu;
 class AttachmentStrategy;
 class HeaderStylePlugin;
 class CSSHelper;
 class ViewerPrivate;
+class Viewer;
 
 /**
  * An interface to plug in a handler that is called when
  * an message item has been loaded into the view.
  */
-class Viewer;
 class MESSAGEVIEWER_EXPORT AbstractMessageLoadedHandler
 {
 public:
@@ -87,8 +89,6 @@ private:
     Private *const d;
 };
 
-//TODO(Andras) once only those methods are public that really need to be public, probably export the whole class instead of just some methods
-
 /**
  * This is the main widget for the viewer.
  * See the documentation of ViewerPrivate for implementation details.
@@ -284,6 +284,8 @@ public:
     Q_REQUIRED_RESULT KToggleAction *disableEmoticonAction() const;
     Q_REQUIRED_RESULT KActionMenu *shareServiceUrlMenu() const;
     Q_REQUIRED_RESULT HeaderStylePlugin *headerStylePlugin() const;
+    Q_REQUIRED_RESULT MessageViewer::DKIMViewerMenu *dkimViewerMenu();
+
     void setPluginName(const QString &pluginName);
 
     void writeConfig(bool withSync = true);
@@ -316,7 +318,7 @@ public:
     */
     void removeMessageLoadedHandler(AbstractMessageLoadedHandler *handler);
 
-    QString selectedText() const;
+    Q_REQUIRED_RESULT QString selectedText() const;
 
     void setExternalWindow(bool b);
 
@@ -324,14 +326,14 @@ public:
     bool mimePartTreeIsEmpty() const;
 
     void showOpenAttachmentFolderWidget(const QList<QUrl> &urls);
-    QList<QAction *> viewerPluginActionList(
+    Q_REQUIRED_RESULT QList<QAction *> viewerPluginActionList(
         MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
-    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
+    Q_REQUIRED_RESULT QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
     void runJavaScript(const QString &code);
     void setPrintElementBackground(bool printElementBackground);
 
-    bool printingMode() const;
+    Q_REQUIRED_RESULT bool printingMode() const;
 
     Q_REQUIRED_RESULT bool showSignatureDetails() const;
     void setShowSignatureDetails(bool showDetails);
@@ -342,6 +344,12 @@ public:
     Q_REQUIRED_RESULT bool showEncryptionDetails() const;
     void setShowEncryptionDetails(bool showDetails);
 
+    void hasMultiMessages(bool messages);
+    void updateShowMultiMessagesButton(bool enablePreviousButton, bool enableNextButton);
+    MessageViewer::DKIMWidgetInfo *dkimWidgetInfo();
+
+    void exportToPdf(const QString &fileName);
+
 Q_SIGNALS:
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
@@ -380,6 +388,8 @@ Q_SIGNALS:
 
     void printingFinished();
     void zoomChanged(qreal zoomFactor);
+    void showNextMessage();
+    void showPreviousMessage();
 
 private:
     void initialize();
@@ -411,7 +421,7 @@ protected:
     void closeEvent(QCloseEvent *) override;
     void resizeEvent(QResizeEvent *) override;
     /** Watch for palette changes */
-    bool event(QEvent *e) override;
+    Q_REQUIRED_RESULT bool event(QEvent *e) override;
     void changeEvent(QEvent *event) override;
 
     ViewerPrivate *const d_ptr;
