@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -250,7 +250,7 @@ void MailWebEngineView::forwardWheelEvent(QWheelEvent *e)
         d->mWebViewAccessKey->wheelEvent(e);
     }
     if (QApplication::keyboardModifiers() & Qt::ControlModifier) {
-        const int numDegrees = e->delta() / 8;
+        const int numDegrees = e->angleDelta().y() / 8;
         const int numSteps = numDegrees / 15;
         Q_EMIT wheelZoomChanged(numSteps);
         e->accept();
