@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,6 +31,10 @@ class WebHitTestResult;
 namespace MessageViewer {
 class ViewerPrivate;
 class MailWebEngineViewPrivate;
+/**
+ * @brief The MailWebEngineView class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT MailWebEngineView : public WebEngineViewer::WebEngineView
 {
     Q_OBJECT
@@ -66,7 +70,7 @@ public:
 
     void setLinkHovered(const QUrl &url);
     void setViewer(MessageViewer::ViewerPrivate *viewer);
-    bool execPrintPreviewPage(QPrinter *printer, int timeout);
+    Q_REQUIRED_RESULT bool execPrintPreviewPage(QPrinter *printer, int timeout);
     void readConfig();
 public Q_SLOTS:
     void slotZoomChanged(qreal zoom);
@@ -100,7 +104,6 @@ private Q_SLOTS:
     void slotWebHitFinished(const WebEngineViewer::WebHitTestResult &result);
     void slotLoadFinished();
 private:
-    void initializeScripts();
     void runJavaScriptInWordId(const QString &script);
     MailWebEngineViewPrivate *const d;
 };
