@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,11 +31,8 @@ using namespace MessageViewer;
 #include <KSyntaxHighlighting/Theme>
 
 #include "PimCommon/PimUtil"
-#include <kiconloader.h>
 #include <KLocalizedString>
-#include <kwindowsystem.h>
 #include <QTabWidget>
-#include <QApplication>
 
 #include <KConfigGroup>
 #include <QShortcut>
@@ -84,11 +81,6 @@ MailSourceWebEngineViewer::MailSourceWebEngineViewer(QWidget *parent)
     shortcut->setKey(Qt::Key_W + Qt::CTRL);
     connect(shortcut, &QShortcut::activated, this, &MailSourceWebEngineViewer::close);
 
-    KWindowSystem::setIcons(winId(),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),
-                                                      IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),
-                                                      IconSize(KIconLoader::Small)));
     mRawBrowser->textBrowser()->setFocus();
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &MailSourceWebEngineViewer::reject);
