@@ -57,7 +57,9 @@ class MessagePartPrivate;
 namespace Interface {
 class ObjectTreeSource;
 }
-
+/**
+ * @brief The MessagePart class
+ */
 class MIMETREEPARSER_EXPORT MessagePart : public QObject
 {
     Q_OBJECT
@@ -78,11 +80,11 @@ public:
     void setParentPart(MessagePart *parentPart);
     MessagePart *parentPart() const;
 
-    virtual QString text() const;
+    virtual Q_REQUIRED_RESULT QString text() const;
     void setText(const QString &text);
 
-    virtual QString plaintextContent() const;
-    virtual QString htmlContent() const;
+    virtual Q_REQUIRED_RESULT QString plaintextContent() const;
+    virtual Q_REQUIRED_RESULT QString htmlContent() const;
 
     /** The KMime::Content* node that's represented by this part.
      *  Can be @c nullptr, e.g. for sub-parts of an inline signed body part.
@@ -96,25 +98,25 @@ public:
      */
     KMime::Content *attachmentContent() const;
     void setAttachmentContent(KMime::Content *node);
-    bool isAttachment() const;
+    Q_REQUIRED_RESULT bool isAttachment() const;
     /** @see KMime::Content::index() */
-    QString attachmentIndex() const;
+    Q_REQUIRED_RESULT QString attachmentIndex() const;
     /** @see NodeHelper::asHREF */
-    QString attachmentLink() const;
+    Q_REQUIRED_RESULT QString attachmentLink() const;
 
     /** Returns a string representation of an URL that can be used
      *  to invoke a BodyPartURLHandler for this body part.
      */
-    QString makeLink(const QString &path) const;
+    Q_REQUIRED_RESULT QString makeLink(const QString &path) const;
 
     void setIsRoot(bool root);
-    bool isRoot() const;
+    Q_REQUIRED_RESULT bool isRoot() const;
 
     virtual bool isHtml() const;
 
-    bool neverDisplayInline() const;
+    Q_REQUIRED_RESULT bool neverDisplayInline() const;
     void setNeverDisplayInline(bool displayInline);
-    bool isImage() const;
+    Q_REQUIRED_RESULT bool isImage() const;
     void setIsImage(bool image);
 
     PartMetaData *partMetaData() const;
@@ -127,12 +129,15 @@ public:
 
     void appendSubPart(const MessagePart::Ptr &messagePart);
     const QVector<MessagePart::Ptr> &subParts() const;
-    bool hasSubParts() const;
+    Q_REQUIRED_RESULT bool hasSubParts() const;
     void clearSubParts();
 
     Interface::ObjectTreeSource *source() const;
     NodeHelper *nodeHelper() const;
 
+    virtual Q_REQUIRED_RESULT bool hasHeader(const char *header) const;
+    virtual KMime::Headers::Base *header(const char *header) const;
+
 protected:
     void parseInternal(KMime::Content *node, bool onlyOneMimePart);
     QString renderInternalText() const;
@@ -142,7 +147,9 @@ protected:
 private:
     std::unique_ptr<MessagePartPrivate> d;
 };
-
+/**
+ * @brief The MimeMessagePart class
+ */
 class MIMETREEPARSER_EXPORT MimeMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -151,14 +158,16 @@ public:
     MimeMessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, bool onlyOneMimePart);
     ~MimeMessagePart() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
-    QString plaintextContent() const override;
-    QString htmlContent() const override;
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString htmlContent() const override;
 private:
     bool mOnlyOneMimePart;
 };
-
+/**
+ * @brief The MessagePartList class
+ */
 class MIMETREEPARSER_EXPORT MessagePartList : public MessagePart
 {
     Q_OBJECT
@@ -167,10 +176,10 @@ public:
     explicit MessagePartList(MimeTreeParser::ObjectTreeParser *otp);
     ~MessagePartList() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
-    QString plaintextContent() const override;
-    QString htmlContent() const override;
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString htmlContent() const override;
 };
 
 enum IconType {
@@ -178,7 +187,9 @@ enum IconType {
     IconExternal,
     IconInline
 };
-
+/**
+ * @brief The TextMessagePart class
+ */
 class MIMETREEPARSER_EXPORT TextMessagePart : public MessagePartList
 {
     Q_OBJECT
@@ -195,18 +206,18 @@ public:
     KMMsgSignatureState signatureState() const;
     KMMsgEncryptionState encryptionState() const;
 
-    bool decryptMessage() const;
+    Q_REQUIRED_RESULT bool decryptMessage() const;
 
-    bool showLink() const;
-    bool isFirstTextPart() const;
-    bool hasLabel() const;
+    Q_REQUIRED_RESULT bool showLink() const;
+    Q_REQUIRED_RESULT bool isFirstTextPart() const;
+    Q_REQUIRED_RESULT bool hasLabel() const;
 
     /** The attachment filename, or the closest approximation thereof we have. */
-    QString label() const;
+    Q_REQUIRED_RESULT QString label() const;
     /** A description of this attachment, if provided. */
-    QString comment() const;
+    Q_REQUIRED_RESULT QString comment() const;
     /** Temporary file containing the part content. */
-    QString temporaryFilePath() const;
+    Q_REQUIRED_RESULT QString temporaryFilePath() const;
 
 private:
     void parseContent();
@@ -215,7 +226,9 @@ private:
     KMMsgEncryptionState mEncryptionState;
     bool mDecryptMessage;
 };
-
+/**
+ * @brief The AttachmentMessagePart class
+ */
 class MIMETREEPARSER_EXPORT AttachmentMessagePart : public TextMessagePart
 {
     Q_OBJECT
@@ -224,7 +237,9 @@ public:
     AttachmentMessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, bool decryptMessage);
     ~AttachmentMessagePart() override;
 };
-
+/**
+ * @brief The HtmlMessagePart class
+ */
 class MIMETREEPARSER_EXPORT HtmlMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -233,20 +248,22 @@ public:
     HtmlMessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, MimeTreeParser::Interface::ObjectTreeSource *source);
     ~HtmlMessagePart() override;
 
-    QString text() const override;
-    QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString text() const override;
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
 
     void fix() const override;
-    bool isHtml() const override;
+    Q_REQUIRED_RESULT bool isHtml() const override;
 
-    QString bodyHtml() const;
+    Q_REQUIRED_RESULT QString bodyHtml() const;
 
 private:
     Interface::ObjectTreeSource *mSource;
     QString mBodyHTML;
     QByteArray mCharset;
 };
-
+/**
+ * @brief The AlternativeMessagePart class
+ */
 class MIMETREEPARSER_EXPORT AlternativeMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -255,17 +272,17 @@ public:
     AlternativeMessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, Util::HtmlMode preferredMode);
     ~AlternativeMessagePart() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
-    Util::HtmlMode preferredMode() const;
+    Q_REQUIRED_RESULT Util::HtmlMode preferredMode() const;
     void setPreferredMode(Util::HtmlMode preferredMode);
 
-    bool isHtml() const override;
+    Q_REQUIRED_RESULT bool isHtml() const override;
 
-    QString plaintextContent() const override;
-    QString htmlContent() const override;
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString htmlContent() const override;
 
-    QList<Util::HtmlMode> availableModes();
+    Q_REQUIRED_RESULT QList<Util::HtmlMode> availableModes();
 
     void fix() const override;
 
@@ -277,7 +294,9 @@ private:
     QMap<Util::HtmlMode, KMime::Content *> mChildNodes;
     QMap<Util::HtmlMode, MimeMessagePart::Ptr> mChildParts;
 };
-
+/**
+ * @brief The CertMessagePart class
+ */
 class MIMETREEPARSER_EXPORT CertMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -286,7 +305,7 @@ public:
     CertMessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, const QGpgME::Protocol *cryptoProto, bool autoImport);
     ~CertMessagePart() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
     const GpgME::ImportResult &importResult() const;
 
@@ -295,7 +314,9 @@ private:
     GpgME::ImportResult mImportResult;
     const QGpgME::Protocol *mCryptoProto;
 };
-
+/**
+ * @brief The EncapsulatedRfc822MessagePart class
+ */
 class MIMETREEPARSER_EXPORT EncapsulatedRfc822MessagePart : public MessagePart
 {
     Q_OBJECT
@@ -304,7 +325,7 @@ public:
     EncapsulatedRfc822MessagePart(MimeTreeParser::ObjectTreeParser *otp, KMime::Content *node, const KMime::Message::Ptr &message);
     ~EncapsulatedRfc822MessagePart() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
     void fix() const override;
 
@@ -313,7 +334,9 @@ public:
 private:
     const KMime::Message::Ptr mMessage;
 };
-
+/**
+ * @brief The EncryptedMessagePart class
+ */
 class MIMETREEPARSER_EXPORT EncryptedMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -327,51 +350,60 @@ public:
 
     ~EncryptedMessagePart() override;
 
-    QString text() const override;
+    Q_REQUIRED_RESULT QString text() const override;
 
     void setDecryptMessage(bool decrypt);
-    bool decryptMessage() const;
+    Q_REQUIRED_RESULT bool decryptMessage() const;
 
     void setIsEncrypted(bool encrypted);
-    bool isEncrypted() const;
+    Q_REQUIRED_RESULT bool isEncrypted() const;
 
-    bool isDecryptable() const;
+    Q_REQUIRED_RESULT bool isDecryptable() const;
 
-    bool isNoSecKey() const;
-    bool passphraseError() const;
+    Q_REQUIRED_RESULT bool isNoSecKey() const;
+    Q_REQUIRED_RESULT bool passphraseError() const;
 
     void startDecryption(const QByteArray &text, const QTextCodec *aCodec);
     void startDecryption(KMime::Content *data = nullptr);
 
-    QByteArray mDecryptedData;
+    void setMementoName(const QByteArray &name);
+    Q_REQUIRED_RESULT QByteArray mementoName() const;
 
-    QString plaintextContent() const override;
-    QString htmlContent() const override;
+
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString htmlContent() const override;
 
     const QGpgME::Protocol *cryptoProto() const;
-    QString fromAddress() const;
+    Q_REQUIRED_RESULT QString fromAddress() const;
 
     const std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key> > &decryptRecipients() const;
 
+    Q_REQUIRED_RESULT bool hasHeader(const char *header) const override;
+    KMime::Headers::Base *header(const char *header) const override;
+
+    QByteArray mDecryptedData;
 private:
     /** Handles the decryption of a given content
      * returns true if the decryption was successful
      * if used in async mode, check if mMetaData.inPogress is true, it initiates a running decryption process.
      */
-    bool okDecryptMIME(KMime::Content &data);
+    Q_REQUIRED_RESULT bool okDecryptMIME(KMime::Content &data);
 
 protected:
     bool mPassphraseError;
     bool mNoSecKey;
+    bool mDecryptMessage;
     const QGpgME::Protocol *mCryptoProto;
     QString mFromAddress;
-    bool mDecryptMessage;
     QByteArray mVerifiedText;
+    QByteArray mMementoName;
     std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key> > mDecryptRecipients;
 
     friend class EncryptedBodyPartFormatter;
 };
-
+/**
+ * @brief The SignedMessagePart class
+ */
 class MIMETREEPARSER_EXPORT SignedMessagePart : public MessagePart
 {
     Q_OBJECT
@@ -383,27 +415,32 @@ public:
     ~SignedMessagePart() override;
 
     void setIsSigned(bool isSigned);
-    bool isSigned() const;
+    Q_REQUIRED_RESULT bool isSigned() const;
 
     void startVerification(const QByteArray &text, const QTextCodec *aCodec);
     void startVerificationDetached(const QByteArray &text, KMime::Content *textNode, const QByteArray &signature);
 
+    void setMementoName(const QByteArray &name);
+    Q_REQUIRED_RESULT QByteArray mementoName() const;
+
     QByteArray mDecryptedData;
     std::vector<GpgME::Signature> mSignatures;
 
-    QString plaintextContent() const override;
-    QString htmlContent() const override;
+    Q_REQUIRED_RESULT QString plaintextContent() const override;
+    Q_REQUIRED_RESULT QString htmlContent() const override;
 
     const QGpgME::Protocol *cryptoProto() const;
-    QString fromAddress() const;
+    Q_REQUIRED_RESULT QString fromAddress() const;
 
+    Q_REQUIRED_RESULT bool hasHeader(const char *header) const override;
+    KMime::Headers::Base *header(const char *header) const override;
 private:
     /** Handles the verification of data
      * If signature is empty it is handled as inline signature otherwise as detached signature mode.
      * Returns true if the verification was successful and the block is signed.
      * If used in async mode, check if mMetaData.inProgress is true, it initiates a running verification process.
      */
-    bool okVerify(const QByteArray &data, const QByteArray &signature, KMime::Content *textNode);
+    Q_REQUIRED_RESULT bool okVerify(const QByteArray &data, const QByteArray &signature, KMime::Content *textNode);
 
     void sigStatusToMetaData();
 
@@ -412,6 +449,7 @@ protected:
     const QGpgME::Protocol *mCryptoProto;
     QString mFromAddress;
     QByteArray mVerifiedText;
+    QByteArray mMementoName;
 
     friend EncryptedMessagePart;
 };
