@@ -20,6 +20,7 @@
 #include "nodehelper.h"
 #include "mimetreeparser_debug.h"
 #include "partmetadata.h"
+#include "messagepart.h"
 #include "interfaces/bodypart.h"
 #include "temporaryfile/attachmenttemporaryfilesdirs.h"
 
@@ -29,16 +30,16 @@
 
 #include <QTemporaryFile>
 #include <KLocalizedString>
-#include <kcharsets.h>
+#include <KCharsets>
 
 #include <QUrl>
 #include <QDir>
 #include <QTextCodec>
+#include <QRegularExpressionMatch>
 
 #include <string>
 #include <sstream>
 #include <algorithm>
-#include <KCharsets>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QFileDevice>
@@ -108,7 +109,7 @@ void NodeHelper::setNodeUnprocessed(KMime::Content *node, bool recurse)
     mProcessedNodes.removeAll(node);
 
     //avoid double addition of extra nodes, eg. encrypted attachments
-    const QMap<KMime::Content *, QList<KMime::Content *> >::iterator it = mExtraContents.find(node);
+    const QMap<KMime::Content *, QVector<KMime::Content *> >::iterator it = mExtraContents.find(node);
     if (it != mExtraContents.end()) {
         Q_FOREACH (KMime::Content *c, it.value()) {
             KMime::Content *p = c->parent();
@@ -159,9 +160,9 @@ void NodeHelper::clear()
     std::for_each(mBodyPartMementoMap.begin(), mBodyPartMementoMap.end(),
                   &clearBodyPartMemento);
     mBodyPartMementoMap.clear();
-    QMap<KMime::Content *, QList<KMime::Content *> >::ConstIterator end(mExtraContents.constEnd());
+    QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator end(mExtraContents.constEnd());
 
-    for (QMap<KMime::Content *, QList<KMime::Content *> >::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
+    for (QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
         Q_FOREACH (KMime::Content *c, it.value()) {
             KMime::Content *p = c->parent();
             if (p) {
@@ -498,6 +499,64 @@ void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
     node->contentType()->setMimeType(mimetype.toLatin1());
 }
 
+bool NodeHelper::hasMailHeader(const char *header, const KMime::Content *message) const
+{
+    return message->hasHeader(header);
+}
+
+KMime::Headers::Base const *NodeHelper::mailHeaderAsBase(const char *header, const KMime::Content *message) const
+{
+    if (mHeaderOverwrite.contains(message)) {
+        foreach (const auto messagePart, mHeaderOverwrite.value(message)) {
+            if (messagePart->hasHeader(header)) {
+                return messagePart->header(header); // Found.
+            }
+        }
+    }
+    return message->headerByType(header);
+}
+
+KMime::Headers::Generics::AddressList const *NodeHelper::mailHeaderAsAddressList(const char *header, const KMime::Content *message) const
+{
+    /* works without this is maybe faster ?
+    if(strcmp(header, "to") == 0) {
+        return message->to();
+    } else if(strcmp(header, "replyTo") == 0) {
+        return message->replyTo();
+    } else if(strcmp(header, "bcc") == 0) {
+        return message->bcc();
+    } else if(strcmp(header, "cc") == 0) {
+        return message->cc();
+    } */
+    auto addressList = new KMime::Headers::Generics::AddressList();
+    const auto hrd = mailHeaderAsBase(header, message);
+    const QByteArray &data = hrd->as7BitString(false);
+    addressList->from7BitString(data);
+    return addressList;
+}
+
+void NodeHelper::clearOverrideHeaders()
+{
+    mHeaderOverwrite.clear();
+}
+
+void NodeHelper::registerOverrideHeader(KMime::Content *message, MessagePart::Ptr part)
+{
+    if (!mHeaderOverwrite.contains(message)) {
+        mHeaderOverwrite[message] = QVector<MessagePart::Ptr>();
+    }
+    mHeaderOverwrite[message].append(part);
+}
+
+QDateTime NodeHelper::dateHeader(KMime::Content *message) const
+{
+    const auto dateHeader = mailHeaderAsBase("date", message);
+    if (dateHeader != nullptr) {
+        return static_cast<const KMime::Headers::Date *>(dateHeader)->dateTime();
+    }
+    return QDateTime();
+}
+
 void NodeHelper::setOverrideCodec(KMime::Content *node, const QTextCodec *codec)
 {
     if (!node) {
@@ -632,7 +691,7 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
 
     QString indexStr = node->index().toString();
     if (indexStr.isEmpty()) {
-        QMapIterator<KMime::Message::Content *, QList<KMime::Content *> > it(mExtraContents);
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
         while (it.hasNext()) {
             it.next();
             const auto &extraNodes = it.value();
@@ -650,10 +709,10 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
     } else {
         const KMime::Content *const topLevel = node->topLevel();
         //if the node is an extra node, prepend the index of the extra node to the url
-        QMapIterator<KMime::Message::Content *, QList<KMime::Content *> > it(mExtraContents);
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
         while (it.hasNext()) {
             it.next();
-            const QList<KMime::Content *> &extraNodes = extraContents(it.key());
+            const QVector<KMime::Content *> &extraNodes = extraContents(it.key());
             for (int i = 0; i < extraNodes.size(); ++i) {
                 KMime::Content *const extraNode = extraNodes[i];
                 if (topLevel == extraNode) {
@@ -675,12 +734,16 @@ KMime::Content *NodeHelper::contentFromIndex(KMime::Content *node, const QString
 {
     KMime::Content *c = node->topLevel();
     if (c) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), QString::SkipEmptyParts);
+#else
+        const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#endif
         const int pathPartsSize(pathParts.size());
         for (int i = 0; i < pathPartsSize; ++i) {
             const QString &path = pathParts[i];
             if (path.startsWith(QLatin1Char('e'))) {
-                const QList<KMime::Content *> &extraParts = mExtraContents.value(c);
+                const QVector<KMime::Content *> &extraParts = mExtraContents.value(c);
                 const int idx = path.midRef(1, -1).toInt();
                 c = (idx < extraParts.size()) ? extraParts[idx] : nullptr;
             } else {
@@ -709,24 +772,33 @@ KMime::Content *NodeHelper::fromHREF(const KMime::Message::Ptr &mMessage, const
         return contentFromIndex(mMessage.data(), url.adjusted(QUrl::StripTrailingSlash).path());
     } else {
         const QString path = url.toLocalFile();
-        // extract from /<path>/qttestn28554.index.2.3:0:2/unnamed -> "2.3:0:2"
-        // start of the index is something that is not a number followed by a dot: \D.
-        // index is only made of numbers,"." and ":": ([0-9.:]+)
-        // index is the last part of the folder name: /
-        const QRegExp rIndex(QStringLiteral("\\D\\.([e0-9.:]+)/"));
-
-        //search the occurrence at most at the end
-        if (rIndex.lastIndexIn(path) != -1) {
-            return contentFromIndex(mMessage.data(), rIndex.cap(1));
+        const QString extractedPath = extractAttachmentIndex(path);
+        if (!extractedPath.isEmpty()) {
+            return contentFromIndex(mMessage.data(), extractedPath);
         }
         return mMessage.data();
     }
 }
 
+QString NodeHelper::extractAttachmentIndex(const QString &path) const
+{
+    // extract from /<path>/qttestn28554.index.2.3:0:2/unnamed -> "2.3:0:2"
+    // start of the index is something that is not a number followed by a dot: \D.
+    // index is only made of numbers,"." and ":": ([0-9.:]+)
+    // index is the last part of the folder name: /
+    const QRegularExpression re(QStringLiteral("\\D\\.([e0-9.:]+)/"));
+    QRegularExpressionMatch rmatch;
+    path.lastIndexOf(re, -1, &rmatch);
+    if (rmatch.hasMatch()) {
+        return rmatch.captured(1);
+    }
+    return QString();
+}
+
 QString NodeHelper::fixEncoding(const QString &encoding)
 {
     QString returnEncoding = encoding;
-    // According to http://www.iana.org/assignments/character-sets, uppercase is
+    // According to https://www.iana.org/assignments/character-sets, uppercase is
     // preferred in MIME headers
     const QString returnEncodingToUpper = returnEncoding.toUpper();
     if (returnEncodingToUpper.contains(QLatin1String("ISO "))) {
@@ -771,7 +843,7 @@ QString NodeHelper::fromAsString(KMime::Content *node) const
         return topLevel->from()->asUnicodeString();
     } else {
         auto realNode = std::find_if(mExtraContents.cbegin(), mExtraContents.cend(),
-                                     [node](const QList<KMime::Content *> &nodes) {
+                                     [node](const QVector<KMime::Content *> &nodes) {
                 return nodes.contains(node);
             });
         if (realNode != mExtraContents.cend()) {
@@ -794,7 +866,7 @@ void NodeHelper::cleanExtraContent(KMime::Content *topLevelNode)
     mExtraContents[topLevelNode].clear();
 }
 
-QList< KMime::Content * > NodeHelper::extraContents(KMime::Content *topLevelnode) const
+QVector< KMime::Content * > NodeHelper::extraContents(KMime::Content *topLevelnode) const
 {
     return mExtraContents.value(topLevelnode);
 }
@@ -805,7 +877,7 @@ void NodeHelper::mergeExtraNodes(KMime::Content *node)
         return;
     }
 
-    const QList<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content * > extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         if (node->bodyIsMessage()) {
             qCWarning(MIMETREEPARSER_LOG) << "Asked to attach extra content to a kmime::message, this does not make sense. Attaching to:" << node
@@ -828,7 +900,7 @@ void NodeHelper::cleanFromExtraNodes(KMime::Content *node)
     if (!node) {
         return;
     }
-    const QList<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content * > extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         QByteArray s = extra->encodedContent();
         const auto children = node->contents();
@@ -871,7 +943,7 @@ KMime::Message *NodeHelper::messageWithExtraContent(KMime::Content *topLevelNode
 
 KMime::Content *NodeHelper::decryptedNodeForContent(KMime::Content *content) const
 {
-    const QList<KMime::Content *> xc = extraContents(content);
+    const QVector<KMime::Content *> xc = extraContents(content);
     if (!xc.empty()) {
         if (xc.size() == 1) {
             return xc.front();
