@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2011-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <QRegularExpression>
 #include <QStringList>
 using namespace TemplateParser;
 
@@ -123,3 +124,96 @@ QStringList TemplateParser::Util::keywords()
                                  << QStringLiteral("%SIGNATURE");
     return keywords;
 }
+
+QString TemplateParser::Util::getFirstNameFromEmail(const QString &str)
+{
+    // simple logic:
+    // if there is ',' in name, than format is 'Last, First'
+    // else format is 'First Last'
+    // last resort -- return 'name' from 'name@domain'
+    int sep_pos;
+    QString res;
+    if ((sep_pos = str.indexOf(QLatin1Char('@'))) > 0) {
+        int i;
+        for (i = (sep_pos - 1); i >= 0; --i) {
+            QChar c = str[i];
+            if (c.isLetterOrNumber()) {
+                res.prepend(c);
+            } else {
+                break;
+            }
+        }
+    } else if ((sep_pos = str.indexOf(QLatin1Char(','))) > 0) {
+        int i;
+        bool begin = false;
+        const int strLength(str.length());
+        for (i = sep_pos; i < strLength; ++i) {
+            QChar c = str[i];
+            if (c.isLetterOrNumber()) {
+                begin = true;
+                res.append(c);
+            } else if (begin) {
+                break;
+            }
+        }
+    } else {
+        int i;
+        const int strLength(str.length());
+        for (i = 0; i < strLength; ++i) {
+            QChar c = str[i];
+            if (c.isLetterOrNumber()) {
+                res.append(c);
+            } else {
+                break;
+            }
+        }
+    }
+    return res;
+}
+
+QString TemplateParser::Util::getLastNameFromEmail(const QString &str)
+{
+    // simple logic:
+    // if there is ',' in name, than format is 'Last, First'
+    // else format is 'First Last'
+    int sep_pos;
+    QString res;
+    if ((sep_pos = str.indexOf(QLatin1Char(','))) > 0) {
+        int i;
+        for (i = sep_pos; i >= 0; --i) {
+            QChar c = str[i];
+            if (c.isLetterOrNumber()) {
+                res.prepend(c);
+            } else {
+                break;
+            }
+        }
+    } else {
+        if ((sep_pos = str.indexOf(QLatin1Char(' '))) > 0) {
+            bool begin = false;
+            const int strLength(str.length());
+            for (int i = sep_pos; i < strLength; ++i) {
+                QChar c = str[i];
+                if (c.isLetterOrNumber()) {
+                    begin = true;
+                    res.append(c);
+                } else if (begin) {
+                    break;
+                }
+            }
+        }
+    }
+    return res;
+}
+
+QString TemplateParser::Util::removeSpaceAtBegin(const QString &selection)
+{
+    QString content = selection;
+    // Remove blank lines at the beginning:
+    const int firstNonWS = content.indexOf(QRegularExpression(QLatin1String("\\S")));
+    const int lineStart = content.lastIndexOf(QLatin1Char('\n'), firstNonWS);
+    if (lineStart >= 0) {
+        content.remove(0, lineStart);
+    }
+    return content;
+}
