@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,6 +30,8 @@
 #include <QFileDialog>
 #include <QWebEngineProfile>
 #include <QPrinter>
+#include <qtwebenginewidgetsversion.h>
+
 using namespace WebEngineViewer;
 
 WebEnginePage::WebEnginePage(QObject *parent)
@@ -80,7 +82,12 @@ void WebEnginePage::saveHtml(QWebEngineDownloadItem *download)
     const QString fileName = QFileDialog::getSaveFileName(view(), i18n("Save HTML Page"));
     if (!fileName.isEmpty()) {
         download->setSavePageFormat(QWebEngineDownloadItem::SingleHtmlSaveFormat);
+#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        download->setDownloadDirectory(QFileInfo(fileName).path());
+        download->setDownloadFileName(QFileInfo(fileName).fileName());
+#else
         download->setPath(fileName);
+#endif
         download->accept();
     }
 }
