@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -140,7 +140,7 @@ QString WebEngineScript::scrollPercentage(int percent)
 
 QString WebEngineScript::scrollUp(int pixel)
 {
-    const QString source = QString::fromLatin1("window.scrollBy(0, %1);").arg(-pixel);
+    const QString source = QStringLiteral("window.scrollBy(0, %1);").arg(-pixel);
     return source;
 }
 
